==> java.util-1.0.3.jar: jdk/util/Formatter$BigDecimalLayoutForm.clj <==
(ns jdk.util.Formatter$BigDecimalLayoutForm
  (:refer-clojure :only [require comment defn ->])
  (:import [java.util Formatter$BigDecimalLayoutForm]))

(def SCIENTIFIC
  "Enum Constant.

  Format the BigDecimal in computerized scientific notation.

  type: java.util.Formatter.BigDecimalLayoutForm"
  Formatter$BigDecimalLayoutForm/SCIENTIFIC)

(def DECIMAL_FLOAT
  "Enum Constant.

  Format the BigDecimal as a decimal number.

  type: java.util.Formatter.BigDecimalLayoutForm"
  Formatter$BigDecimalLayoutForm/DECIMAL_FLOAT)

(defn *values
  "Returns an array containing the constants of this enum type, in
  the order they are declared.  This method may be used to iterate
  over the constants as follows:


  for (Formatter.BigDecimalLayoutForm c : Formatter.BigDecimalLayoutForm.values())
      System.out.println(c);

  returns: an array containing the constants of this enum type, in the order they are declared - `java.util.Formatter.BigDecimalLayoutForm[]`"
  ([]
    (Formatter$BigDecimalLayoutForm/values )))

(defn *value-of
  "Returns the enum constant of this type with the specified name.
  The string must match exactly an identifier used to declare an
  enum constant in this type.  (Extraneous whitespace characters are
  not permitted.)

  name - the name of the enum constant to be returned. - `java.lang.String`

  returns: the enum constant with the specified name - `java.util.Formatter.BigDecimalLayoutForm`

  throws: java.lang.IllegalArgumentException - if this enum type has no constant with the specified name"
  (^java.util.Formatter.BigDecimalLayoutForm [^java.lang.String name]
    (Formatter$BigDecimalLayoutForm/valueOf name)))

==> java.util-1.0.4.jar: jdk/util/Formatter$BigDecimalLayoutForm.clj <==
(ns jdk.util.Formatter$BigDecimalLayoutForm
  (:refer-clojure :only [require comment defn ->])
  (:import [java.util Formatter$BigDecimalLayoutForm]))

(def SCIENTIFIC
  "Enum Constant.

  Format the BigDecimal in computerized scientific notation.

  type: java.util.Formatter$BigDecimalLayoutForm"
  Formatter$BigDecimalLayoutForm/SCIENTIFIC)

(def DECIMAL_FLOAT
  "Enum Constant.

  Format the BigDecimal as a decimal number.

  type: java.util.Formatter$BigDecimalLayoutForm"
  Formatter$BigDecimalLayoutForm/DECIMAL_FLOAT)

(defn *values
  "Returns an array containing the constants of this enum type, in
  the order they are declared.  This method may be used to iterate
  over the constants as follows:


  for (Formatter.BigDecimalLayoutForm c : Formatter.BigDecimalLayoutForm.values())
      System.out.println(c);

  returns: an array containing the constants of this enum type, in the order they are declared - `java.util.Formatter$BigDecimalLayoutForm[]`"
  ([]
    (Formatter$BigDecimalLayoutForm/values )))

(defn *value-of
  "Returns the enum constant of this type with the specified name.
  The string must match exactly an identifier used to declare an
  enum constant in this type.  (Extraneous whitespace characters are
  not permitted.)

  name - the name of the enum constant to be returned. - `java.lang.String`

  returns: the enum constant with the specified name - `java.util.Formatter$BigDecimalLayoutForm`

  throws: java.lang.IllegalArgumentException - if this enum type has no constant with the specified name"
  (^java.util.Formatter$BigDecimalLayoutForm [^java.lang.String name]
    (Formatter$BigDecimalLayoutForm/valueOf name)))
